The concept of direct alpha is closely related to the KS PME as it uses the
same method to calculate an IRR which is then compared to the fund’s IRR.
However, the difference between KS PME and direct alpha method is that in
direct alpha the under or out performance is quantified by calculating the
compounded cash flows plus the fund’s NAV.

See also:
- <https://en.wikipedia.org/wiki/Public_Market_Equivalent#Direct_Alpha>
- <https://blog.edda.co/advanced-fund-performance-methods-pme-direct-alpha/>
